<?php

/*
 * LMS version 1.4.5 Persus
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: language.php,v 1.8.2.2 2005/01/01 19:19:26 alec Exp $
 */

// Plik do ustawiania locales i do translacji...
// Chwilowo tutaj nie ma nic, naprawd nic, poprostu potrzebne do eksperymentw paru.

// ustawienie komunikatw syst. na polskie
setlocale(LC_MESSAGES,'pl_PL');
// ustawienie formatu czasu na polski
setlocale(LC_TIME,'pl_PL');
// kapitalizowanie literek
setlocale(LC_CTYPE,'pl_PL');

?>